# rendering

two crucial constraints hold when translating markdown to python:

1. minimal changes to generate valid python code from markdown
2. line-for-line translation between the languages

#### code fences